% Latex abstract template for ECCOMAS Thematic Conference and IACM Special Interest Conference HFSS 2023, Rijeka, Croatia

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{hfss2023}
\ProcessOptions\relax

\DeclareOption{11pt}{\OptionNotUsed}
\DeclareOption{twocolumn}{\OptionNotUsed}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
  
\ProcessOptions\relax
  
\LoadClass[11pt,a4paper,twoside]{article}
  
\RequirePackage{ucs}		 % extended UTF-8 input encoding support for LaTeX - CTAN
\RequirePackage[utf8x]{inputenc}
\RequirePackage{mathptmx}	 % use Adobe Times Roman (or equivalent) as default text font and provide maths support.
\RequirePackage[T1]{fontenc}

%\RequirePackage[dvipdfmx]{graphicx}
\RequirePackage{graphicx}
\RequirePackage{verbatim}
\RequirePackage{tabularx}
\RequirePackage{amsmath,amsfonts,amssymb,amsthm,amsbsy,amsmath}
\RequirePackage{latexsym}
\RequirePackage{bm}
\RequirePackage{a4}
\RequirePackage{fancyhdr}
\RequirePackage{engord}
\RequirePackage{epsfig,vmargin,booktabs}
\RequirePackage{grffile}
\RequirePackage{float}
\RequirePackage{fix-cm}
\newcommand{\size}[2]{{\fontsize{#1}{0}\selectfont#2}}
\newenvironment{sizepar}[2]
{\par\fontsize{#1}{#2}\selectfont}
{\par}
\bibliographystyle{unsrt}

\setpapersize{A4}  		% needs vmargin package
\setmarginsrb{20.0mm}{5mm}{20.0mm}{20mm}{20mm}{0mm}{0mm}{0mm}
\parindent=0.0em
\parskip=1.0ex

\renewcommand{\thesection}{\arabic{section}.}
\renewcommand{\thesubsection}{\arabic{section}.\arabic{subsection}.}
\renewcommand{\thesubsubsection}{\arabic{section}.\arabic{subsection}.\arabic{subsubsection}}

% SECTIONS 
\renewcommand\section{\@startsection {section}{1}{\z@}{-11pt}{0.2ex}{\normalsize\bf}}
%
% SUBSECTIONS 
\renewcommand\subsection{\@startsection {subsection}{1}{\z@}{-11pt}{4pt}{\normalsize\bf}}

\renewenvironment{thebibliography}[1]
  {\section*{\fontsize{11}{11}\refname\@mkboth{\MakeUppercase\refname}{\MakeUppercase\refname}}%
   \list{\@biblabel{\@arabic\c@enumiv}}%
        {\settowidth\labelwidth{\@biblabel{#1}}%
         \leftmargin\labelwidth
         \advance\leftmargin\labelsep
         \@openbib@code
         \usecounter{enumiv}%
         \let\p@enumiv\@empty
         \renewcommand\theenumiv{\@arabic\c@enumiv}}%
   \sloppy
   \clubpenalty4000
   \@clubpenalty \clubpenalty
   \widowpenalty4000%
   \sfcode`\.\@m}
  {\def\@noitemerr
   {\@latex@warning{Empty `thebibliography' environment}}%
   \endlist}

\newlength{\bibitemsep}\setlength{\bibitemsep}{.2\baselineskip plus .05\baselineskip minus .05\baselineskip}
\newlength{\bibparskip}\setlength{\bibparskip}{0pt}
\let\oldthebibliography\thebibliography
\renewcommand\thebibliography[1]{%
  \oldthebibliography{#1}%
  \setlength{\parskip}{\bibitemsep}%
  \setlength{\itemsep}{\bibparskip}%
}

\AtBeginDocument{%    
  \pagestyle{empty}
  \thispagestyle{fancy}
  \fancyhf{} % clear all header and footer fields
  \renewcommand{\headrulewidth}{0pt}
  \rhead{
    \scriptsize{
     ECCOMAS Thematic Conference and IACM Special Interest Conference \\
       Highly Flexible Slender Structures (HFSS 2025) \\
       22–26 September 2025, Kaiserslautern, Germany
      \vspace{5mm}
    }
  }
}
\endinput

%%% Additional settings like font sizes etc.
\def\figurename{Figure}
\def\tablename{Table}
